==> skrooge-0.2.5.tar.gz: skrooge-0.2.5/skgbasegui/skgcombobox.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGCOMBOBOX_H
#define SKGCOMBOBOX_H
/** @file
 * A combo box for skrooge.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */

#include <kcombobox.h>
#include <QtDesigner/QDesignerExportWidget>

/**
 * This file is a combo box for skrooge.
 */
class KDE_EXPORT SKGComboBox : public KComboBox
{
        Q_OBJECT
        Q_PROPERTY( QString text READ text WRITE setText USER true)

public:
        /**
         * Default Constructor
         * @param parent the parent
         */
        SKGComboBox(QWidget *parent = 0);

        /**
         * Default Destructor
         */
        virtual ~SKGComboBox();

        /**
         * Get the text for the combo
         * @return the text
         */
        virtual QString text() const;


        /**
         * Set the text for the combo
         * @param iText the text
         */
        virtual void setText (const QString& iText);

private:
        Q_DISABLE_COPY(SKGComboBox);


};

#endif // SKGCOMBOBOX_H

==> skrooge-0.5.2.tar.gz: skrooge-0.5.2/skgbasegui/skgcombobox.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGCOMBOBOX_H
#define SKGCOMBOBOX_H
/** @file
 * A combo box for skrooge.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */

#include <kcombobox.h>
#include <QtDesigner/QDesignerExportWidget>
#include "skgbasegui_export.h"
/**
 * This file is a combo box for skrooge.
 */
class SKGBASEGUI_EXPORT SKGComboBox : public KComboBox
{
        Q_OBJECT
        Q_PROPERTY( QString text READ text WRITE setText USER true)

public:
        /**
         * Default Constructor
         * @param parent the parent
         */
        SKGComboBox(QWidget *parent = 0);

        /**
         * Default Destructor
         */
        virtual ~SKGComboBox();

        /**
         * Get the text for the combo
         * @return the text
         */
        virtual QString text() const;


        /**
         * Set the text for the combo
         * @param iText the text
         */
        virtual void setText (const QString& iText);

private:
        Q_DISABLE_COPY(SKGComboBox);


};

#endif // SKGCOMBOBOX_H
